Phenotypic metrics
i
Phenotype severity is not displayed when phenotype evaluation is binary (presence/absence).
Phenotypes similarity: 1 - 100
XXX_PHENOTYPE_SEVERITY
Biological annotations
Genotype
Homo
Hetero
Hemi
Sex
Female
Male
Life stage
i
Early: -16w, Interval: 17-48w, Late: 49w-
Embryo
Early
Interval
Late
XXX_CY_CONTAINER
Highlight
Markup
Human Disease
i
Human Disease annotations use IMPC Disease Models. Genes associated with human diseases are highlighted with a red border.

i
Search for phenotypes to highlight. Genes with matching phenotypes are highlighted with a blue border.

Node size
Centrality:
i
'Normalized' options divide the centrality score by the number of phenotypes observed in KO mice
Scale: 0
Display
Layout:
Font size: 20
Edge width: 5
Node repulsion: 5